@@ -33,6 +33,7 @@
  */
 #include <stdio.h>
 #include <signal.h>
+#include <fcntl.h>
 
 #ifdef _WIN32
 /* Fucking windows doesn't have getopt? */
@@ -1408,12 +1409,12 @@ Connect(PalmSyncInfo *pi)
     signal(SIGSEGV, SigHandler);
 #endif
     
-    if (!(sd = pi_socket(PI_AF_SLP, PI_SOCK_STREAM, PI_PF_PADP))) {
+    if (!(sd = pi_socket(PI_AF_PILOT, PI_SOCK_STREAM, PI_PF_DLP))) {
         perror("pi_socket");
         exit(1);
     }
     
-    addr.pi_family = PI_AF_SLP;
+    addr.pi_family = PI_AF_PILOT;
     strcpy(addr.pi_device, device);
     
     ret = pi_bind(sd, (struct sockaddr*)&addr, sizeof(addr));
